@@ -1,6 +1,6 @@
-package Pod::Elemental::PerlMunger;
+package Pod::Elemental::PerlMunger 0.200007;
 # ABSTRACT: a thing that takes a string of Perl and rewrites its documentation
-$Pod::Elemental::PerlMunger::VERSION = '0.200005';
+
 use Moose::Role;
 
 #pod =head1 OVERVIEW
@@ -19,9 +19,16 @@ use Moose::Role;
 #pod
 #pod C<$perl_string> should be a character string containing Perl source code.
 #pod
-#pod C<%arg> may contain any input for the underlying procedure.  The only key with
-#pod associated meaning is C<filename> which may be omitted.  If given, it should be
-#pod the name of the file whose contents are being munged.
+#pod C<%arg> may contain any input for the underlying procedure.  Defined keys for
+#pod C<%arg> are:
+#pod
+#pod =for :list
+#pod = filename
+#pod the name of the file whose contents are being munged; optional, used for error
+#pod messages
+#pod = no_strip_bom
+#pod If given, the BOM character (U+FEFF) won't be stripped from the input.
+#pod Probably best to leave this one off.
 #pod
 #pod The method will return a character string containing the rewritten and combined
 #pod document.
@@ -53,9 +60,9 @@ requires 'munge_perl_string';
 around munge_perl_string => sub {
   my ($orig, $self, $perl, $arg) = @_;
 
-  my $perl_utf8 = Encode::encode('utf-8', $perl, Encode::FB_CROAK);
+  $perl =~ s/^\x{FEFF}// unless $arg->{no_strip_bom};
 
-  my $ppi_document = PPI::Document->new(\$perl_utf8);
+  my $ppi_document = PPI::Document->new(\$perl);
   confess(PPI::Document->errstr) unless $ppi_document;
 
   my $last_code_elem;
@@ -127,8 +134,9 @@ around munge_perl_string => sub {
   # TODO: I should add a $weaver->weave_* like the Linewise methods to take the
   # input, get a Document, perform the stock transformations, and then weave.
   # -- rjbs, 2009-10-24
-  my $pod_str = join "\n", @pod_tokens;
-  my $pod_document = Pod::Elemental->read_string($pod_str);
+  my $pod_str  = join "\n", @pod_tokens;
+  my $pod_utf8 = Encode::encode('utf-8', $pod_str, Encode::FB_CROAK);
+  my $pod_document = Pod::Elemental->read_string($pod_utf8);
 
   my $doc = $self->$orig(
     {
@@ -161,25 +169,12 @@ around munge_perl_string => sub {
 
   $doc->{ppi}->prune($end_finder);
 
-  my $new_perl = Encode::decode(
-    'utf-8',
-    $doc->{ppi}->serialize,
-    Encode::FB_CROAK,
-  );
+  my $new_perl = $doc->{ppi}->serialize;
 
   s/\n\s*\z// for $new_perl, $new_pod;
 
-  my $new_end;
-  if (defined $end) {
-    $new_end = Encode::decode(
-      'utf-8',
-      $end,
-      Encode::FB_CROAK,
-    );
-  }
-
   return defined $end
-         ? "$new_perl\n\n$new_pod\n\n$new_end"
+         ? "$new_perl\n\n$new_pod\n\n$end"
          : "$new_perl\n\n__END__\n\n$new_pod\n";
 };
 
@@ -306,7 +301,7 @@ Pod::Elemental::PerlMunger - a thing that takes a string of Perl and rewrites it
 
 =head1 VERSION
 
-version 0.200005
+version 0.200007
 
 =head1 OVERVIEW
 
@@ -324,9 +319,22 @@ this:
 
 C<$perl_string> should be a character string containing Perl source code.
 
-C<%arg> may contain any input for the underlying procedure.  The only key with
-associated meaning is C<filename> which may be omitted.  If given, it should be
-the name of the file whose contents are being munged.
+C<%arg> may contain any input for the underlying procedure.  Defined keys for
+C<%arg> are:
+
+=over 4
+
+=item filename
+
+the name of the file whose contents are being munged; optional, used for error
+messages
+
+=item no_strip_bom
+
+If given, the BOM character (U+FEFF) won't be stripped from the input.
+Probably best to leave this one off.
+
+=back
 
 The method will return a character string containing the rewritten and combined
 document.
@@ -344,6 +352,16 @@ C<%doc> will have two entries:
 This C<munge_perl_string> method should return a hashref in the same format as
 C<%doc>.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 replacer
@@ -408,11 +426,11 @@ line count.  In other words:
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Christopher J. Madsen Dave Rolsky Karen Etheridge perlancar (on PC, Bandung)
+=for stopwords Christopher J. Madsen Dave Rolsky Karen Etheridge perlancar (on PC, Bandung) Ricardo Signes
 
 =over 4
 
@@ -432,11 +450,15 @@ Karen Etheridge <ether@cpan.org>
 
 perlancar (on PC, Bandung) <perlancar@gmail.com>
 
+=item *
+
+Ricardo Signes <rjbs@semiotic.systems>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
